qwif
=====

Generate QR codes for WIFI and more from the command line.

Requirements
------------

* python 3.8+

Installing
-----------

Install and update using [pip](https://pip.pypa.io/en/stable/quickstart/):

```
pip install -U qwif
```

Alternatively, you can package and run `qwif` in a docker container:

```
make image
```


Authors
--------

* [iwaseatenbyagrue](https://gitlab.com/iwaseatenbyagrue)
